@@ -17,7 +17,6 @@ from adtk.detector import LevelShiftAD
 from cimetrics.env import get_env
 
 plt.style.use("ggplot")
-matplotlib.rcParams["text.hinting"] = 1
 
 
 class Color:
@@ -29,13 +28,6 @@ class Color:
     BACKGROUND = "white"
 
 
-class StandardFontSize:
-    XTICKS = 6
-    YTICKS = 6
-    TITLE = 8
-    DEFAULT = 6
-
-
 class SmallFontSize:
     XTICKS = 4
     YTICKS = 4
@@ -43,6 +35,13 @@ class SmallFontSize:
     DEFAULT = 4
 
 
+class StandardFontSize:
+    XTICKS = 4
+    YTICKS = 4
+    TITLE = 5
+    DEFAULT = 4
+
+
 def ticklabel_format(value):
     """
     Pick formatter for ytick labels. If possible, just print out the
@@ -88,7 +87,7 @@ class Metrics(object):
                 f" Make sure you create the {env.config_file} file at the root of your repo."
             )
 
-    def branch_history(self, branch, max_build_id=None, max_builds=5):
+    def branch_history(self, branch_query, max_build_id=None, max_builds=5):
         """
         Branch history as a dataframe, up to max_build_id, going back
         at most max_builds.
@@ -108,8 +107,7 @@ class Metrics(object):
             return v
 
         # Discover build ids by descending order of created timestamp
-        query = {"branch": branch}
-        records = self.col.find(query, {"build_id": 1, "created": 1}).sort(
+        records = self.col.find(branch_query, {"build_id": 1, "created": 1}).sort(
             [("created", pymongo.DESCENDING)]
         )
 
@@ -128,7 +126,8 @@ class Metrics(object):
                     break
 
         # Get metrics for those build ids, ordered by build_ids
-        query = {"branch": branch, "build_id": {"$in": list(build_ids)}}
+        query = branch_query.copy()
+        query["build_id"] = {"$in": list(build_ids)}
         records = self.col.find(
             query, {"build_id": 1, "metrics": 1, "build_number": 1}
         ).sort([("build_id", pymongo.ASCENDING)])
@@ -178,7 +177,9 @@ def trend_view(env, tgt_only=False):
     # calculated from a full window
     build_span = span + env.ewma_span
 
-    tgt_raw, tick_map = m.branch_history(env.target_branch, max_builds=build_span)
+    tgt_raw, tick_map = m.branch_history(
+        {"branch": env.target_branch}, max_builds=build_span
+    )
     tgt_ewma = tgt_raw.ewm(span=env.ewma_span).mean()
     tgt_cols = tgt_raw.columns
     tgt_raw = tgt_raw.tail(span)
@@ -193,12 +194,20 @@ def trend_view(env, tgt_only=False):
         fig = plt.figure(figsize=fsize)
         font_size = SmallFontSize
     else:
-        branch_series, branch_tick_map = m.branch_history(env.branch, env.build_id)
+        # On a PR, select older builds with the same PR id (assumed unique)
+        # failing that, use the branch name, in which case we may pick up
+        # uninteresting history if the branch name has been reused.
+        if env.pull_request_id:
+            query = {"pr_id": env.pull_request_id}
+        else:
+            query = {"branch": env.branch}
+        branch_series, branch_tick_map = m.branch_history(query, env.build_id)
         tick_map.update(branch_tick_map)
         columns = sorted(branch_series.columns)
         ncol = env.columns
-        dpi_adjust = 1
-        fig = plt.figure()
+        fsize = matplotlib.figure.figaspect(1)
+        dpi_adjust = fsize[1] / matplotlib.rcParams["figure.figsize"][1]
+        fig = plt.figure(figsize=fsize)
         font_size = StandardFontSize
 
     # There is no easy way to set the size on annotate(), but we
@@ -289,8 +298,9 @@ def trend_view(env, tgt_only=False):
                         [bx, bx],
                         [lewm, by],
                         color=good_col if by < lewm else bad_col,
-                        linestyle=":",
+                        linestyle="-",
                         linewidth=1,
+                        alpha=0.3,
                     )
 
                 if col in tgt_ewma:
@@ -390,8 +400,21 @@ def trend_view(env, tgt_only=False):
     else:
         comment = f"WARNING: {env.target_branch} does not have any data"
     print(comment)
+
+    build_number = [tick_map[tgt_raw.index.values[i]] for i in range(len(tgt_raw))]
+    tgt_raw.insert(loc=0, column="build_number", value=build_number)
+    disable_numparse = [1]  # 0 is the index (build_id), 1 is build_number
+    md = f"""
+<details>
+  <summary>Click to see table</summary>
+  
+  {tgt_raw.to_markdown(disable_numparse=disable_numparse)}
+</details>
+"""
+
     with open(os.path.join(metrics_path, "diff.txt"), "w") as dtext:
         dtext.write(comment)
+        dtext.write(md)
 
 
 if __name__ == "__main__":
